==> views_data_export_phpspreadsheet-8.x-1.0.tar.gz: views_data_export_phpspreadsheet/src/Plugin/views/style/XlsxExport.php <==
<?php

namespace Drupal\views_data_export_phpspreadsheet\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Drupal\views_data_export\Plugin\views\style\DataExport;
use Drupal\views\Plugin\views\style\AttachableStyleInterface;

/**
 * A style plugin for data export views.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "data_export",
 *   title = @Translation("Xlsx export"),
 *   help = @Translation("Configurable row output for excel exports."),
 *   display_types = {"data"}
 * )
 */
class XlsxExport extends DataExport {

  use RedirectDestinationTrait;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, $serializer, array $serializer_formats, array $serializer_format_providers) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer, $serializer_formats, $serializer_format_providers);
    $this->formats[] = 'xls';
    $this->formatProviders['xls'] = 'serialization';
  }

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    $options = parent::defineOptions();
    // XLS color options.
    $options['xls_settings']['contains'] = [
      'xls_format' => ['default' => 'xlsx'],
    ];
    if($this->displayHandler){
      $fields = $this->displayHandler->getOption('fields');
      foreach ($fields as $field=>$field_setting){
        $options['xls_settings']['contains']['color'][$field] = ['default' => null];
      }
    }
    return $options;
  }
  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    switch ($form_state->get('section')) {
      case 'style_options':

        $format_options = $this->getFormatOptions();
        if (in_array('xls', $format_options)) {
          $form['xls_settings']['xls_format' ]['#options'] = [
            'xlsx' => t('Excel 2007'),
            'xls' => t('Excel 95'),
            'xml' => t('Excel xml 2003'),
            'ods' => t('Open Document Format'),
            'slk' => t('Symbolic Link Interchange'),
            'gnumeric' => t('Gnome Gnumeric'),
            'csv' => t('Csv'),
          ];
          //add heeader && footer because rest_export doesn't support
          $form['xls_settings']['header'] = [
            '#title' => t('Print header'),
            '#type' => 'text_format',
            '#rows' => 4,
            '#editor' => FALSE,
            '#format' => filter_default_format(),
            '#default_value' => !empty($xls_options['header']) ? $xls_options['header'] : null,
          ];
          $form['xls_settings']['footer'] = [
            '#title' => t('Print footer'),
            '#type' => 'text_format',
            '#rows' => 4,
            '#editor' => FALSE,
            '#format' => filter_default_format(),
            '#default_value' => !empty($xls_options['footer']) ? $xls_options['footer'] : null,
          ];
          $form['xls_settings']['color'] = [
            '#title' => t('Color column'),
            '#type' => 'details',
            '#tree' => TRUE,
            '#states' => [
              'visible' => [
                ':input[name="style_options[formats]"]' => [
                  ['value' => 'xls'],
                  ['value' => 'xlsx'],
                ],
              ],
            ]
          ];

          $xls_options = $this->options['xls_settings'];
          $fields = $this->displayHandler->getOption('fields');
          foreach ($fields as $field=>$field_setting){
            if(!$field_setting['exclude']){
              $form['xls_settings']['color'][$field] = [
                '#type'=>'color',
                '#title'=> !empty($field_setting['label']) ? $field_setting['label'] : $field,
                '#default_value' => !empty($xls_options['color'][$field]) ? $xls_options['color'][$field] : null,
              ];
            }
          }
        }
        break;
    }
  }

}

==> views_data_export_phpspreadsheet-8.x-1.1.tar.gz: views_data_export_phpspreadsheet/src/Plugin/views/style/XlsxExport.php <==
<?php

namespace Drupal\views_data_export_phpspreadsheet\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Drupal\views_data_export\Plugin\views\style\DataExport;
use Drupal\views\Plugin\views\style\AttachableStyleInterface;

/**
 * A style plugin for data export views.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "data_export",
 *   title = @Translation("Xlsx export"),
 *   help = @Translation("Configurable row output for excel exports."),
 *   display_types = {"data"}
 * )
 */
class XlsxExport extends DataExport {

  use RedirectDestinationTrait;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, $serializer, array $serializer_formats, array $serializer_format_providers) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer, $serializer_formats, $serializer_format_providers);
    $this->formats[] = 'xls';
    $this->formatProviders['xls'] = 'serialization';
    $this->formats[] = 'xlsx';
    $this->formatProviders['xlsx'] = 'serialization';
    $this->formats[] = 'ods';
    $this->formatProviders['ods'] = 'serialization';
    $this->formats[] = 'slk';
    $this->formatProviders['slk'] = 'serialization';
    $this->formats[] = 'gnumeric';
    $this->formatProviders['gnumeric'] = 'serialization';
  }

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    $options = parent::defineOptions();
    // XLS color options.
    if($this->displayHandler){
      $fields = $this->displayHandler->getOption('fields');
      foreach ($fields as $field=>$field_setting){
        $options['xls_settings']['contains']['color'][$field] = ['default' => null];
      }
    }
    return $options;
  }
  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    switch ($form_state->get('section')) {
      case 'style_options':
        $form['xls_settings']['#states']['visible'][':input[name="style_options[formats]"]'] = [
          ['value' => 'xls'],
          ['value' => 'xlsx'],
          ['value' => 'ods'],
          ['value' => 'slk'],
          ['value' => 'gnumeric'],
        ];
        unset($form['xls_settings']['xls_format']);
        $format_options = $this->getFormatOptions();
        if (in_array('xls', $format_options)) {
          //add heeder && footer because rest_export doesn't support
          $form['xls_settings']['header'] = [
            '#title' => t('Print header'),
            '#type' => 'text_format',
            '#rows' => 4,
            '#editor' => FALSE,
            '#format' => filter_default_format(),
            '#default_value' => !empty($xls_options['header']) ? $xls_options['header'] : null,
          ];
          $form['xls_settings']['footer'] = [
            '#title' => t('Print footer'),
            '#type' => 'text_format',
            '#rows' => 4,
            '#editor' => FALSE,
            '#format' => filter_default_format(),
            '#default_value' => !empty($xls_options['footer']) ? $xls_options['footer'] : null,
          ];
          $form['xls_settings']['color'] = [
            '#title' => t('Color column'),
            '#type' => 'details',
            '#tree' => TRUE,
            '#states' => [
              'visible' => [
                ':input[name="style_options[formats]"]' => [
                  ['value' => 'xls'],
                  ['value' => 'xlsx'],
                  ['value' => 'ods'],
                  ['value' => 'slk'],
                ],
              ],
            ]
          ];

          $xls_options = $this->options['xls_settings'];
          $fields = $this->displayHandler->getOption('fields');
          foreach ($fields as $field=>$field_setting){
            if(!$field_setting['exclude']){
              $form['xls_settings']['color'][$field] = [
                '#type'=>'color',
                '#title'=> !empty($field_setting['label']) ? $field_setting['label'] : $field,
                '#default_value' => !empty($xls_options['color'][$field]) ? $xls_options['color'][$field] : null,
              ];
            }
          }
        }
        break;
    }
  }

}
